'use strict';

var errors = require('@backstage/errors');
var express = require('express');
var Router = require('express-promise-router');

function _interopDefaultCompat (e) { return e && typeof e === 'object' && 'default' in e ? e : { default: e }; }

var express__default = /*#__PURE__*/_interopDefaultCompat(express);
var Router__default = /*#__PURE__*/_interopDefaultCompat(Router);

async function createRouter(options) {
  const router = Router__default.default();
  router.use(express__default.default.json());
  const getUserEntityRef = async (req) => {
    const credentials = await options.httpAuth.credentials(req, {
      allow: ["user"]
    });
    return credentials.principal.userEntityRef;
  };
  router.get("/buckets/:bucket/keys/:key", async (req, res) => {
    const userEntityRef = await getUserEntityRef(req);
    const { bucket, key } = req.params;
    const setting = await options.userSettingsStore.get({
      userEntityRef,
      bucket,
      key
    });
    res.json(setting);
  });
  router.put("/buckets/:bucket/keys/:key", async (req, res) => {
    const userEntityRef = await getUserEntityRef(req);
    const { bucket, key } = req.params;
    const { value } = req.body;
    if (value === void 0) {
      throw new errors.InputError('Missing required field "value"');
    }
    await options.userSettingsStore.set({
      userEntityRef,
      bucket,
      key,
      value
    });
    const setting = await options.userSettingsStore.get({
      userEntityRef,
      bucket,
      key
    });
    if (options.signals) {
      await options.signals.publish({
        recipients: { type: "user", entityRef: userEntityRef },
        channel: `user-settings`,
        message: { type: "key-changed", key }
      });
    }
    res.json(setting);
  });
  router.delete("/buckets/:bucket/keys/:key", async (req, res) => {
    const userEntityRef = await getUserEntityRef(req);
    const { bucket, key } = req.params;
    await options.userSettingsStore.delete({ userEntityRef, bucket, key });
    if (options.signals) {
      await options.signals.publish({
        recipients: { type: "user", entityRef: userEntityRef },
        channel: "user-settings",
        message: { type: "key-deleted", key }
      });
    }
    res.status(204).end();
  });
  return router;
}

exports.createRouter = createRouter;
//# sourceMappingURL=router.cjs.js.map
